OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Koledar",
    "Individual" : "Posamezno",
    "Group" : "Skupina",
    "Resource" : "Vir",
    "Room" : "Soba",
    "Unknown" : "Neznano",
    "Required" : "Zahtevano",
    "Optional" : "Izbirno",
    "Does not attend" : "Ni udeleženec",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Ni mogoče določiti časovnega pasu ({tz}), zato bo prikazan čas UTC",
    "Please create a calendar first." : "Najprej je treba ustvariti koledar.",
    "New event" : "Nov dogodek",
    "Error saving WebCal-calendar" : "Napaka shranjevanja koledarja WebCal",
    "group" : "skupina",
    "Attendees" : "Udeleženci",
    "Reminders" : "Opomniki",
    "Repeating" : "Ponavljanje",
    "When shared show full event" : "Če je v souporabi, pokaži celoten dogodek",
    "When shared show only busy" : "Če je v souporabi, pokaži le podatek o časovni zadržanosti",
    "When shared hide this event" : "Če je v souporabi, skrij ta dogodek",
    "Confirmed" : "Potrjeno",
    "Tentative" : "Začasno",
    "Cancelled" : "Preklicano",
    "Please add a title!" : "Dodajte naslov!",
    "Please select a calendar!" : "Izberite koledar!",
    "Global" : "Splošno",
    "None" : "Brez",
    "Every day" : "Vsak dan",
    "Every week" : "Vsak teden",
    "Every month" : "Vsak mesec",
    "Every year" : "Vsako leto",
    "never" : "nikoli",
    "after" : "po",
    "At time of event" : "Ob času dogodka",
    "5 minutes before" : "5 minut prej",
    "10 minutes before" : "10 minut prej",
    "15 minutes before" : "15 minut prej",
    "30 minutes before" : "30 minut prej",
    "1 hour before" : "1 uro prej",
    "2 hours before" : "2 uri prej",
    "Custom" : "Po meri",
    "Audio" : "Zvok",
    "E Mail" : "Elektronska pošta",
    "Pop up" : "Pojavno okno",
    "sec" : "sek",
    "min" : "najmanj",
    "hours" : "ur",
    "days" : "dni",
    "week" : "teden",
    "before" : "pred",
    "start" : "začetek",
    "end" : "konec",
    "Editing reminders of unknown type not supported." : "Urejanje opomnikov neznane vrste ni podprto.",
    "Week {number} of {year}" : "{number}. teden leta {year}",
    "Successfully imported" : "Uvoz uspešno končan",
    "Partially imported, 1 failure" : "Delno uvoženo, zaznana je 1 napaka",
    "Partially imported, {n} failures" : "Delno uvoženo, zaznanih je {n} napak",
    "Audio alarm" : "Zvočni alarm",
    "Pop-up" : "Pojavno okno",
    "E-Mail" : "Elektronska pošta",
    "{type} {time} before the event starts" : "{type} {time} preden se dogodek začne",
    "{type} {time} before the event ends" : "{type} {time} preden se dogodek konča",
    "{type} {time} after the event starts" : "{type} {time} po začetku dogodka",
    "{type} {time} after the event ends" : "{type} {time} po koncu dogodka",
    "{type} at the event's start" : "{type} ob začetku dogodka",
    "{type} at the event's end" : "{type} ob koncu dogodka",
    "{type} at {time}" : "{type} ob {time}",
    "{calendar} shared by {owner}" : "{calendar} je objavila oseba {owner}",
    "Please enter a valid WebCal-URL" : "Vpišite veljaven naslov URL WebCal",
    "Title of the Event" : "Naslov dogodka",
    "starts" : "začetek",
    "ends" : "konec",
    "All day Event" : "Celodnevni dogodek",
    "Delete" : "Izbriši",
    "Cancel" : "Prekliči",
    "More ..." : "Več ...",
    "Create" : "Ustvari",
    "Update" : "Posodobi",
    "Close" : "Zapri",
    "Location" : "Mesto",
    "Description" : "Opis",
    "Event status" : "Stanje dogodka",
    "Visibility when sharing" : "Vidnost med souporabo",
    "Export" : "Izvozi",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Zaradi znanega hrošča v koledarju trenutno ni mogoča podpora zmožnosti skrčenja kode javascript in CSS.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Stopite v stik s sistemskim skrbnikom oziroma onemogočite nastavitev \"asset-pipeline.enabled\"",
    "Day" : "Dan",
    "Week" : "Teden",
    "Month" : "Mesec",
    "Today" : "Danes",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Nekateri vpisani dogodki v koledarju so okvarjeni. Preverite konzolo JS za več podrobnosti.",
    "Share Calendar" : "Omogoči souporabo koledarja",
    "Shared" : "V souporabi",
    "More" : "Več",
    "Edit" : "Uredi",
    "Link" : "Povezava",
    "WebCal URL" : "Naslov URL WebCal",
    "Download" : "Prejmi",
    "Share with users or groups" : "Souporaba z uporabniki ali skupinami",
    "can edit" : "lahko ureja",
    "New Calendar" : "Nov koledar",
    "Name" : "Ime",
    "New Subscription" : "Novo naročilo",
    "WebCal-URL" : "WebCal-URL",
    "Edit event" : "Uredi dogodek",
    "Delete Event" : "Izbriši dogodek",
    "Save Event" : "Shrani dogodek",
    "Time" : "Čas",
    "Type" : "Vrsta",
    "Relative" : "Relativno",
    "Absolute" : "Absolutno",
    "Repeat" : "Ponovi",
    "times every" : "krat vsakih",
    "Add" : "Dodaj",
    "E-Mail address of attendee" : "Elektronski naslov udeleženca",
    "Please add your email address in the personal settings in order to add attendees." : "Dodati morate vaš elektronski naslov med osebne nastavitve, preden je mogoče dodajati udeležence",
    "from" : "od",
    "to" : "za",
    "This event's repeating rule is not supported yet." : "Ponavljajoče pravilo tega dogodka še ni podprto.",
    "Support for advanced rules will be added with subsequent updates." : "Podpora naprednejšim pravilom bo dodana z naslednjimi posodobitvami.",
    "Reset repeating rule" : "Ponastavi ponavljajoče se pravilo",
    "Repeat every ..." : "Ponovi na ..",
    "end repeat ..." : "in ponovi ...",
    "times" : "krat",
    "Import Calendars" : "Uvoz koledarjev",
    "Import canceled" : "Uvoz je preklican",
    "Analyzing calendar" : "Preučevanje koledarja",
    "The file contains objects incompatible with the selected calendar" : "Datoteka vsebuje predmete, ki so neskladne z izbranim koledarjem",
    "New calendar" : "Nov koledar",
    "Import scheduled" : "Uvoz urnika",
    "Settings" : "Nastavitve",
    "Skip simple event editor" : "Preskoči enostavni urejevalnik dogodkov",
    "Show week numbers" : "Pokaži številke tednov",
    "Import calendar" : "Uvoz koledarja",
    "No Calendars selected for import" : "Ni navedenih koledarjev za uvoz",
    "Primary CalDAV address" : "Osnovni naslov CalDAV",
    "iOS/OS X CalDAV address" : "Naslov CalDAV iOS/OS"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
